# NAME

xpymon - A versatile WiFi/network/battery/CPU/video system monitor on Linux

# SYNOPSIS

xpywm

# DESCRIPTION

This manual page documents **xpymon**, a minimal but versatile system monitor
on Linux.  **xpymon** is designed to work with **xpywm**, a simple but
extensible X11 window manager written in Python
(https://pypi.org/project/xpywm/).

**xpymon** consumes the minimum amount of the desktop; i.e., the height of the
statsu monitor window is just eight pixels.

# OPTIONS

- -T

  Run in test mode.

# REQUIREMENTS

The implementation of **xpymon** heavily depends on the Linux kernel (/proc
and /sys pseudo filesystems) and its standard utilities such as ip (iproute2),
ifconfig (net-tools), and iwconfig (wireless-tools).

# INSTALLATION

```sh
$ sudo apt install iproute2 net-tools wireless-tools 
$ pip3 install xpymon
```

# AVAILABILITY

The latest version of **ansiterm** module is available at PyPI
(https://pypi.org/project/xpymon/) .

# SEE ALSO

xpywm(1), ip(8), iwconfig(8), ifconfig(8), xrandr(1), zdump(8), proc(5)

# AUTHOR

Hiroyuki Ohsaki <ohsaki[atmark]lsnl.jp>
